@@ -8,7 +8,6 @@
 #' Most of those functions have been replaced by alternative 'update' ones.
 #'
 #' @export add_parent
-#'
 add_parent <- function() {
   .Deprecated(
     new = "update_concept", package = "taxlist",
@@ -17,11 +16,8 @@ add_parent <- function() {
 }
 
 #' @rdname Deprecated-functions
-#'
 #' @aliases add_trait
-#'
 #' @export add_trait
-#'
 add_trait <- function() {
   .Deprecated(
     new = "update_trait", package = "taxlist",
@@ -30,11 +26,8 @@ add_trait <- function() {
 }
 
 #' @rdname Deprecated-functions
-#'
 #' @aliases add_level
-#'
 #' @export add_level
-#'
 add_level <- function() {
   .Deprecated(
     package = "taxlist",
@@ -46,11 +39,8 @@ add_level <- function() {
 }
 
 #' @rdname Deprecated-functions
-#'
 #' @aliases replace_view
-#'
 #' @export replace_view
-#'
 replace_view <- function() {
   .Deprecated(
     new = "update_concept", package = "taxlist",
@@ -62,11 +52,8 @@ replace_view <- function() {
 }
 
 #' @rdname Deprecated-functions
-#'
 #' @aliases taxlist2taxmap
-#'
 #' @export taxlist2taxmap
-#'
 taxlist2taxmap <- function() {
   .Deprecated(
     package = "taxlist",
@@ -78,11 +65,8 @@ taxlist2taxmap <- function() {
 }
 
 #' @rdname Deprecated-functions
-#'
 #' @aliases taxmap2taxlist
-#'
 #' @export taxmap2taxlist
-#'
 taxmap2taxlist <- function() {
   .Deprecated(
     package = "taxlist",
@@ -92,3 +76,29 @@ taxmap2taxlist <- function() {
     )
   )
 }
+
+#' @rdname Deprecated-functions
+#' @aliases taxmap2taxlist
+#' @export taxmap2taxlist
+taxmap2taxlist <- function() {
+  .Deprecated(
+    package = "taxlist",
+    msg = paste(
+      "This function is temporarily deprecated",
+      "to avoid conflicts with new version of 'taxa'"
+    )
+  )
+}
+
+#' @rdname Deprecated-functions
+#' @aliases tnrs
+#' @export tnrs
+tnrs <- function() {
+  .Deprecated(
+    package = "taxlist",
+    msg = paste(
+      "'tnrs' is deprecated due to changes in package 'taxize'.",
+      "Check into the documentation of that package for alternatives."
+    )
+  )
+}
